@@ -10,8 +10,6 @@ import tensorflow as tf  # type: ignore
 from .np import (
     flip_left_right,
     flip_up_down,
-    rotate_90,
-    rotate_90_and_pad,
     rotate,
     crop,
     translate,
@@ -19,18 +17,15 @@ from .np import (
 )
 
 from .tf import (
-    np_to_tf,
+    to_tf,
     tf_flip_left_right,
     tf_flip_up_down,
-    tf_rotate_90,
-    tf_rotate_90_and_pad,
     tf_rotate,
     tf_crop,
     tf_translate,
     tf_shear
 )
 
-
 ORIGINAL_IMAGE_LIST = [
     np.array([
         [[1], [2], [3]],
@@ -69,10 +64,9 @@ ORIGINAL_LABELS_LIST = [
     np.array([], dtype=np.float32),
 ]
 
-
 (
     TF_ORIGINAL_IMAGE_LIST, TF_ORIGINAL_BBOXES_LIST, TF_ORIGINAL_LABELS_LIST
-) = np_to_tf(
+) = to_tf(
     ORIGINAL_IMAGE_LIST, ORIGINAL_BBOXES_LIST, ORIGINAL_LABELS_LIST
 )
 
@@ -135,7 +129,7 @@ class TestTransform(unittest.TestCase):
             tf_expected_image_list,
             tf_expected_bboxes_list,
             tf_expected_labels_list
-        ) = np_to_tf(
+        ) = to_tf(
             expected_image_list, expected_bboxes_list, expected_labels_list
         )
         for i in range(len(TF_ORIGINAL_LABELS_LIST)):
@@ -213,7 +207,7 @@ class TestTransform(unittest.TestCase):
             tf_expected_image_list,
             tf_expected_bboxes_list,
             tf_expected_labels_list
-        ) = np_to_tf(
+        ) = to_tf(
             expected_image_list, expected_bboxes_list, expected_labels_list
         )
         for i in range(len(TF_ORIGINAL_LABELS_LIST)):
@@ -235,165 +229,6 @@ class TestTransform(unittest.TestCase):
                                tf_labels.numpy())
             )
 
-    def test_rotate_90(self) -> None:
-
-        expected_image_list = [
-            np.array([
-                [[3], [6], [9], [12]],
-                [[2], [5], [8], [11]],
-                [[1], [4], [7], [10]]
-            ], dtype=np.float32),
-            np.array([
-                [[13], [16], [19], [22]],
-                [[12], [15], [18], [21]],
-                [[11], [14], [17], [20]]
-            ], dtype=np.float32),
-            np.array([
-                [[23], [26], [29], [32]],
-                [[22], [25], [28], [31]],
-                [[21], [24], [27], [30]]
-            ], dtype=np.float32),
-        ]
-        expected_bboxes_list = [
-            np.array([
-                [0, 0, 2, 2],
-                [1, 0, 2, 3],
-            ], dtype=np.float32),
-            np.array([
-                [0, 1, 3, 2],
-            ], dtype=np.float32),
-            np.array([], dtype=np.float32).reshape(-1, 4),
-        ]
-        expected_labels_list = ORIGINAL_LABELS_LIST
-
-        # Numpy.
-        for i in range(len(ORIGINAL_IMAGE_LIST)):
-            image, bboxes, labels = rotate_90(
-                ORIGINAL_IMAGE_LIST[i],
-                ORIGINAL_BBOXES_LIST[i],
-                ORIGINAL_LABELS_LIST[i]
-            )
-            self.assertTrue(
-                np.array_equal(expected_image_list[i], image)
-            )
-            self.assertTrue(
-                np.array_equal(expected_bboxes_list[i], bboxes)
-            )
-            self.assertTrue(
-                np.array_equal(expected_labels_list[i], labels)
-            )
-
-        # TF.
-        (
-            tf_expected_image_list,
-            tf_expected_bboxes_list,
-            tf_expected_labels_list
-        ) = np_to_tf(
-            expected_image_list, expected_bboxes_list, expected_labels_list
-        )
-        for i in range(len(TF_ORIGINAL_LABELS_LIST)):
-            tf_image, tf_bboxes, tf_labels = tf_rotate_90(
-                TF_ORIGINAL_IMAGE_LIST[i],
-                TF_ORIGINAL_BBOXES_LIST[i],
-                TF_ORIGINAL_LABELS_LIST[i]
-            )
-            self.assertTrue(
-                np.array_equal(tf_expected_image_list[i].numpy(),
-                               tf_image.numpy())
-            )
-            self.assertTrue(
-                np.array_equal(tf_expected_bboxes_list[i].numpy(),
-                               tf_bboxes.numpy())
-            )
-            self.assertTrue(
-                np.array_equal(tf_expected_labels_list[i].numpy(),
-                               tf_labels.numpy())
-            )
-
-    def test_rotate_90_and_pad(self) -> None:
-
-        expected_image_list = [
-            np.array([
-                [[0], [0], [0], [0]],
-                [[0], [0], [0], [0]],
-                [[3], [6], [9], [12]],
-                [[2], [5], [8], [11]],
-                [[1], [4], [7], [10]],
-                [[0], [0], [0], [0]]
-            ], dtype=np.float32),
-            np.array([
-                [[0], [0], [0], [0]],
-                [[0], [0], [0], [0]],
-                [[13], [16], [19], [22]],
-                [[12], [15], [18], [21]],
-                [[11], [14], [17], [20]],
-                [[0], [0], [0], [0]]
-            ], dtype=np.float32),
-            np.array([
-                [[0], [0], [0], [0]],
-                [[0], [0], [0], [0]],
-                [[23], [26], [29], [32]],
-                [[22], [25], [28], [31]],
-                [[21], [24], [27], [30]],
-                [[0], [0], [0], [0]]
-            ], dtype=np.float32),
-        ]
-        expected_bboxes_list = [
-            np.array([
-                [0, 2, 2, 2],
-                [1, 2, 2, 3],
-            ], dtype=np.float32),
-            np.array([
-                [0, 3, 3, 2],
-            ], dtype=np.float32),
-            np.array([], dtype=np.float32).reshape(-1, 4),
-        ]
-        expected_labels_list = ORIGINAL_LABELS_LIST
-
-        # Numpy.
-        for i in range(len(ORIGINAL_IMAGE_LIST)):
-            image, bboxes, labels = rotate_90_and_pad(
-                ORIGINAL_IMAGE_LIST[i],
-                ORIGINAL_BBOXES_LIST[i],
-                ORIGINAL_LABELS_LIST[i]
-            )
-            self.assertTrue(
-                np.array_equal(expected_image_list[i], image)
-            )
-            self.assertTrue(
-                np.array_equal(expected_bboxes_list[i], bboxes)
-            )
-            self.assertTrue(
-                np.array_equal(expected_labels_list[i], labels)
-            )
-
-        # TF.
-        (
-            tf_expected_image_list,
-            tf_expected_bboxes_list,
-            tf_expected_labels_list
-        ) = np_to_tf(
-            expected_image_list, expected_bboxes_list, expected_labels_list
-        )
-        for i in range(len(TF_ORIGINAL_LABELS_LIST)):
-            tf_image, tf_bboxes, tf_labels = tf_rotate_90_and_pad(
-                TF_ORIGINAL_IMAGE_LIST[i],
-                TF_ORIGINAL_BBOXES_LIST[i],
-                TF_ORIGINAL_LABELS_LIST[i]
-            )
-            self.assertTrue(
-                np.array_equal(tf_expected_image_list[i].numpy(),
-                               tf_image.numpy())
-            )
-            self.assertTrue(
-                np.array_equal(tf_expected_bboxes_list[i].numpy(),
-                               tf_bboxes.numpy())
-            )
-            self.assertTrue(
-                np.array_equal(tf_expected_labels_list[i].numpy(),
-                               tf_labels.numpy())
-            )
-
     def test_rotate(self) -> None:
 
         original_image_list = [
@@ -466,14 +301,14 @@ class TestTransform(unittest.TestCase):
             tf_original_image_list,
             tf_original_bboxes_list,
             tf_original_labels_list
-        ) = np_to_tf(
+        ) = to_tf(
             original_image_list, original_bboxes_list, original_labels_list
         )
         (
             tf_expected_image_list,
             tf_expected_bboxes_list,
             tf_expected_labels_list
-        ) = np_to_tf(
+        ) = to_tf(
             expected_image_list, expected_bboxes_list, expected_labels_list
         )
         for i in range(len(tf_original_image_list)):
@@ -542,6 +377,88 @@ class TestTransform(unittest.TestCase):
             np.allclose(tf_expected_labels.numpy(), tf_labels.numpy())
         )
 
+    def test_translate(self) -> None:
+
+        translate_heights = [-1, 0, 1]
+        translate_widths = [0, 1, 1]
+
+        expected_image_list = [
+            np.array([
+                [[4], [5], [6]],
+                [[7], [8], [9]],
+                [[10], [11], [12]],
+                [[0], [0], [0]]
+            ], dtype=np.float32),
+            np.array([
+                [[0], [11], [12]],
+                [[0], [14], [15]],
+                [[0], [17], [18]],
+                [[0], [20], [21]]
+            ], dtype=np.float32),
+            np.array([
+                [[0], [0], [0]],
+                [[0], [21], [22]],
+                [[0], [24], [25]],
+                [[0], [27], [28]]
+            ], dtype=np.float32),
+        ]
+        expected_bboxes_list = [
+            np.array([
+                [1, 0, 2, 1],
+                [0, 0, 3, 2],
+            ], dtype=np.float32),
+            np.array([
+                [1, 0, 2, 3],
+            ], dtype=np.float32),
+            np.array([], dtype=np.float32).reshape(-1, 4),
+        ]
+        expected_labels_list = [
+            np.array([0, 1], dtype=np.float32),
+            np.array([2], dtype=np.float32),
+            np.array([], dtype=np.float32),
+        ]
+
+        # Numpy.
+        for i in range(len(ORIGINAL_IMAGE_LIST)):
+            image, bboxes, labels = translate(
+                ORIGINAL_IMAGE_LIST[i],
+                ORIGINAL_BBOXES_LIST[i],
+                ORIGINAL_LABELS_LIST[i],
+                translate_heights[i], translate_widths[i]
+            )
+            self.assertTrue(np.array_equal(expected_image_list[i], image))
+            self.assertTrue(np.array_equal(expected_bboxes_list[i], bboxes))
+            self.assertTrue(np.array_equal(expected_labels_list[i], labels))
+
+        # TF.
+        (
+            tf_expected_image_list,
+            tf_expected_bboxes_list,
+            tf_expected_labels_list
+        ) = to_tf(
+            expected_image_list, expected_bboxes_list, expected_labels_list
+        )
+
+        for i in range(len(TF_ORIGINAL_LABELS_LIST)):
+            tf_image, tf_bboxes, tf_labels = tf_translate(
+                TF_ORIGINAL_IMAGE_LIST[i],
+                TF_ORIGINAL_BBOXES_LIST[i],
+                TF_ORIGINAL_LABELS_LIST[i],
+                translate_heights[i], translate_widths[i]
+            )
+            self.assertTrue(
+                np.array_equal(tf_expected_image_list[i].numpy(),
+                               tf_image.numpy())
+            )
+            self.assertTrue(
+                np.array_equal(tf_expected_bboxes_list[i].numpy(),
+                               tf_bboxes.numpy())
+            )
+            self.assertTrue(
+                np.array_equal(tf_expected_labels_list[i].numpy(),
+                               tf_labels.numpy())
+            )
+
     def test_crop(self) -> None:
 
         dummy_image_list = [np.random.rand(128, 128, 3) for _ in range(4)]
@@ -610,10 +527,10 @@ class TestTransform(unittest.TestCase):
             tf_dummy_image_list,
             tf_original_bboxes_list,
             tf_original_labels_list
-        ) = np_to_tf(
+        ) = to_tf(
             dummy_image_list, original_bboxes_list, original_labels_list
         )
-        _, tf_expected_bboxes_list, tf_expected_labels_list = np_to_tf(
+        _, tf_expected_bboxes_list, tf_expected_labels_list = to_tf(
             dummy_image_list, expected_bboxes_list, expected_labels_list
         )
 
@@ -634,88 +551,6 @@ class TestTransform(unittest.TestCase):
                             tf_labels.numpy())
             )
 
-    def test_translate(self) -> None:
-
-        translate_heights = [-1, 0, 1]
-        translate_widths = [0, 1, 1]
-
-        expected_image_list = [
-            np.array([
-                [[4], [5], [6]],
-                [[7], [8], [9]],
-                [[10], [11], [12]],
-                [[0], [0], [0]]
-            ], dtype=np.float32),
-            np.array([
-                [[0], [11], [12]],
-                [[0], [14], [15]],
-                [[0], [17], [18]],
-                [[0], [20], [21]]
-            ], dtype=np.float32),
-            np.array([
-                [[0], [0], [0]],
-                [[0], [21], [22]],
-                [[0], [24], [25]],
-                [[0], [27], [28]]
-            ], dtype=np.float32),
-        ]
-        expected_bboxes_list = [
-            np.array([
-                [1, 0, 2, 1],
-                [0, 0, 3, 2],
-            ], dtype=np.float32),
-            np.array([
-                [1, 0, 2, 3],
-            ], dtype=np.float32),
-            np.array([], dtype=np.float32).reshape(-1, 4),
-        ]
-        expected_labels_list = [
-            np.array([0, 1], dtype=np.float32),
-            np.array([2], dtype=np.float32),
-            np.array([], dtype=np.float32),
-        ]
-
-        # Numpy.
-        for i in range(len(ORIGINAL_IMAGE_LIST)):
-            image, bboxes, labels = translate(
-                ORIGINAL_IMAGE_LIST[i],
-                ORIGINAL_BBOXES_LIST[i],
-                ORIGINAL_LABELS_LIST[i],
-                translate_heights[i], translate_widths[i]
-            )
-            self.assertTrue(np.array_equal(expected_image_list[i], image))
-            self.assertTrue(np.array_equal(expected_bboxes_list[i], bboxes))
-            self.assertTrue(np.array_equal(expected_labels_list[i], labels))
-
-        # TF.
-        (
-            tf_expected_image_list,
-            tf_expected_bboxes_list,
-            tf_expected_labels_list
-        ) = np_to_tf(
-            expected_image_list, expected_bboxes_list, expected_labels_list
-        )
-
-        for i in range(len(TF_ORIGINAL_LABELS_LIST)):
-            tf_image, tf_bboxes, tf_labels = tf_translate(
-                TF_ORIGINAL_IMAGE_LIST[i],
-                TF_ORIGINAL_BBOXES_LIST[i],
-                TF_ORIGINAL_LABELS_LIST[i],
-                translate_heights[i], translate_widths[i]
-            )
-            self.assertTrue(
-                np.array_equal(tf_expected_image_list[i].numpy(),
-                               tf_image.numpy())
-            )
-            self.assertTrue(
-                np.array_equal(tf_expected_bboxes_list[i].numpy(),
-                               tf_bboxes.numpy())
-            )
-            self.assertTrue(
-                np.array_equal(tf_expected_labels_list[i].numpy(),
-                               tf_labels.numpy())
-            )
-
 
 if __name__ == "__main__":
     unittest.main()
