@@ -1,8 +1,6 @@
 from ._np import (
     flip_left_right,
     flip_up_down,
-    rotate_90,
-    rotate_90_and_pad,
     rotate,
     crop,
     translate,
@@ -11,8 +9,6 @@ from ._np import (
     RandomTransform,
     RandomFlipLeftRight,
     RandomFlipUpDown,
-    RandomRotate90,
-    RandomRotate90AndPad,
     RandomRotate,
     RandomCrop,
     RandomTranslate,
