@@ -20,8 +20,6 @@ from targetran._functional import (
 from targetran._transform import (
     _flip_left_right,
     _flip_up_down,
-    _rotate_90,
-    _rotate_90_and_pad,
     _rotate,
     _shear,
     _crop,
@@ -66,29 +64,6 @@ def resize(
     )
 
 
-def rotate_90(
-        image: np.ndarray,
-        bboxes: np.ndarray,
-        labels: np.ndarray
-) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-    return _rotate_90(
-        image, bboxes, labels,
-        _np_convert, np.shape, np.reshape, np.transpose, np.concatenate
-    )
-
-
-def rotate_90_and_pad(
-        image: np.ndarray,
-        bboxes: np.ndarray,
-        labels: np.ndarray
-) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-    return _rotate_90_and_pad(
-        image, bboxes, labels,
-        _np_convert, np.shape, np.reshape, np.transpose, np.concatenate,
-        np.where, np.ceil, np.floor, _np_pad_image
-    )
-
-
 def rotate(
         image: np.ndarray,
         bboxes: np.ndarray,
@@ -99,8 +74,8 @@ def rotate(
         image, bboxes, labels, angle_deg,
         _np_convert, np.shape, np.reshape, np.expand_dims, np.squeeze,
         _np_pad_image, _np_range, _np_round_to_int, np.repeat, np.tile,
-        np.stack, np.concatenate, np.cos, np.sin, np.matmul, np.clip,
-        _np_gather_image, np.copy, np.max, np.min,
+        np.ones_like, np.stack, np.concatenate, np.cos, np.sin, np.matmul,
+        np.clip, _np_gather_image, np.copy, np.max, np.min,
         _np_logical_and, _np_boolean_mask
     )
 
@@ -115,7 +90,25 @@ def shear(
         image, bboxes, labels, angle_deg,
         _np_convert, np.shape, np.reshape, np.expand_dims, np.squeeze,
         _np_pad_image, _np_range, _np_round_to_int, np.repeat, np.tile,
-        np.stack, np.concatenate, np.tan, np.matmul, np.clip,
+        np.ones_like, np.stack, np.concatenate, np.tan, np.matmul, np.clip,
+        _np_gather_image, np.copy, np.max, np.min,
+        _np_logical_and, _np_boolean_mask
+    )
+
+
+def translate(
+        image: np.ndarray,
+        bboxes: np.ndarray,
+        labels: np.ndarray,
+        translate_height: int,
+        translate_width: int
+) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
+    return _translate(
+        image, bboxes, labels,
+        translate_height, translate_width,
+        _np_convert, np.shape, np.reshape, np.expand_dims, np.squeeze,
+        _np_pad_image, _np_range, _np_round_to_int, np.repeat, np.tile,
+        np.ones_like, np.stack, np.concatenate, np.matmul, np.clip,
         _np_gather_image, np.copy, np.max, np.min,
         _np_logical_and, _np_boolean_mask
     )
@@ -152,21 +145,6 @@ def crop(
     )
 
 
-def translate(
-        image: np.ndarray,
-        bboxes: np.ndarray,
-        labels: np.ndarray,
-        translate_height: int,
-        translate_width: int
-) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-    return _translate(
-        image, bboxes, labels,
-        translate_height, translate_width,
-        _np_convert, np.shape, np.reshape, np.where, np.abs, np.concatenate,
-        _np_logical_and, np.squeeze, np.clip, _np_boolean_mask, _np_pad_image
-    )
-
-
 class Resize:
 
     def __init__(self, dest_size: Tuple[int, int]) -> None:
@@ -202,7 +180,7 @@ class RandomTransform:
             *args: Any,
             **kwargs: Any
     ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-
+        # Make sure inputs are in the needed format.
         image = _np_convert(image)
         bboxes = _np_convert(bboxes)
         labels = _np_convert(labels)
@@ -252,46 +230,6 @@ class RandomFlipUpDown(RandomTransform):
         return super().__call__(image, bboxes, labels)
 
 
-class RandomRotate90(RandomTransform):
-
-    def __init__(
-            self,
-            probability: float = 0.7,
-            seed: Optional[int] = None
-    ) -> None:
-        super().__init__(rotate_90, probability, seed)
-
-    def __call__(
-            self,
-            image: np.ndarray,
-            bboxes: np.ndarray,
-            labels: np.ndarray,
-            *args: Any,
-            **kwargs: Any
-    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-        return super().__call__(image, bboxes, labels)
-
-
-class RandomRotate90AndPad(RandomTransform):
-
-    def __init__(
-            self,
-            probability: float = 0.7,
-            seed: Optional[int] = None
-    ) -> None:
-        super().__init__(rotate_90_and_pad, probability, seed)
-
-    def __call__(
-            self,
-            image: np.ndarray,
-            bboxes: np.ndarray,
-            labels: np.ndarray,
-            *args: Any,
-            **kwargs: Any
-    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-        return super().__call__(image, bboxes, labels)
-
-
 class RandomRotate(RandomTransform):
 
     def __init__(
@@ -312,7 +250,6 @@ class RandomRotate(RandomTransform):
             *args: Any,
             **kwargs: Any
     ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-
         angle_deg = \
             self.angle_deg_range[1] - self.angle_deg_range[0] \
             * self._rand_fn() + self.angle_deg_range[0]
@@ -340,7 +277,6 @@ class RandomShear(RandomTransform):
             *args: Any,
             **kwargs: Any
     ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-
         angle_deg = \
             self.angle_deg_range[1] - self.angle_deg_range[0] \
             * self._rand_fn() + self.angle_deg_range[0]
@@ -348,42 +284,6 @@ class RandomShear(RandomTransform):
         return super().__call__(image, bboxes, labels, angle_deg)
 
 
-class RandomCrop(RandomTransform):
-
-    def __init__(
-            self,
-            crop_height_fraction_range: Tuple[float, float] = (0.7, 0.9),
-            crop_width_fraction_range: Tuple[float, float] = (0.7, 0.9),
-            probability: float = 0.7,
-            seed: Optional[int] = None
-    ) -> None:
-        super().__init__(crop, probability, seed)
-        self.crop_height_fraction_range = crop_height_fraction_range
-        self.crop_width_fraction_range = crop_width_fraction_range
-
-    def __call__(
-            self,
-            image: np.ndarray,
-            bboxes: np.ndarray,
-            labels: np.ndarray,
-            *args: Any,
-            **kwargs: Any
-    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-
-        offset_height, offset_width, cropped_height, cropped_width = \
-            _np_get_random_crop_inputs(
-                np.shape(image)[0], np.shape(image)[1],
-                self.crop_height_fraction_range,
-                self.crop_width_fraction_range,
-                self._rand_fn
-            )
-
-        return super().__call__(
-            image, bboxes, labels,
-            offset_height, offset_width, cropped_height, cropped_width
-        )
-
-
 class RandomTranslate(RandomTransform):
 
     def __init__(
@@ -405,7 +305,6 @@ class RandomTranslate(RandomTransform):
             *args: Any,
             **kwargs: Any
     ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
-
         height_fraction, width_fraction = _get_random_size_fractions(
             self.translate_height_fraction_range,
             self.translate_width_fraction_range,
@@ -422,3 +321,38 @@ class RandomTranslate(RandomTransform):
         return super().__call__(
             image, bboxes, labels, translate_height, translate_width
         )
+
+
+class RandomCrop(RandomTransform):
+
+    def __init__(
+            self,
+            crop_height_fraction_range: Tuple[float, float] = (0.7, 0.9),
+            crop_width_fraction_range: Tuple[float, float] = (0.7, 0.9),
+            probability: float = 0.7,
+            seed: Optional[int] = None
+    ) -> None:
+        super().__init__(crop, probability, seed)
+        self.crop_height_fraction_range = crop_height_fraction_range
+        self.crop_width_fraction_range = crop_width_fraction_range
+
+    def __call__(
+            self,
+            image: np.ndarray,
+            bboxes: np.ndarray,
+            labels: np.ndarray,
+            *args: Any,
+            **kwargs: Any
+    ) -> Tuple[np.ndarray, np.ndarray, np.ndarray]:
+        offset_height, offset_width, cropped_height, cropped_width = \
+            _np_get_random_crop_inputs(
+                np.shape(image)[0], np.shape(image)[1],
+                self.crop_height_fraction_range,
+                self.crop_width_fraction_range,
+                self._rand_fn
+            )
+
+        return super().__call__(
+            image, bboxes, labels,
+            offset_height, offset_width, cropped_height, cropped_width
+        )
