@@ -1,10 +1,8 @@
 from ._tf import (
-    np_to_tf,
+    to_tf,
     seqs_to_tf_dataset,
     tf_flip_left_right,
     tf_flip_up_down,
-    tf_rotate_90,
-    tf_rotate_90_and_pad,
     tf_rotate,
     tf_crop,
     tf_translate,
@@ -13,8 +11,6 @@ from ._tf import (
     TFRandomTransform,
     TFRandomFlipLeftRight,
     TFRandomFlipUpDown,
-    TFRandomRotate90,
-    TFRandomRotate90AndPad,
     TFRandomRotate,
     TFRandomCrop,
     TFRandomTranslate,
