@@ -2,7 +2,7 @@
 API for TensorFlow usage.
 """
 
-from typing import Any, Callable, Optional, Sequence, Tuple
+from typing import Any, Callable, Optional, Sequence, Tuple, TypeVar
 
 import numpy as np  # type: ignore
 import tensorflow as tf  # type: ignore
@@ -15,12 +15,9 @@ from targetran._functional import (
     _tf_gather_image
 )
 
-
 from targetran._transform import (
     _flip_left_right,
     _flip_up_down,
-    _rotate_90,
-    _rotate_90_and_pad,
     _rotate,
     _shear,
     _crop,
@@ -30,14 +27,16 @@ from targetran._transform import (
     _get_random_size_fractions
 )
 
+T = TypeVar("T", np.ndarray, tf.Tensor)
 
-def np_to_tf(
-        image_seq: Sequence[np.ndarray],
-        bboxes_seq: Sequence[np.ndarray],
-        labels_seq: Sequence[np.ndarray]
+
+def to_tf(
+        image_seq: Sequence[T],
+        bboxes_seq: Sequence[T],
+        labels_seq: Sequence[T]
 ) -> Tuple[Sequence[tf.Tensor], Sequence[tf.Tensor], Sequence[tf.Tensor]]:
     """
-    Convert Numpy array seqs to TF (eager) tensor seqs.
+    Convert seqs to TF (eager) tensor seqs.
     """
     tuples = [
         (_tf_convert(image),
@@ -50,12 +49,11 @@ def np_to_tf(
 
 
 def seqs_to_tf_dataset(
-        image_seq: Sequence[np.ndarray],
-        bboxes_seq: Sequence[np.ndarray],
-        labels_seq: Sequence[np.ndarray]
+        image_seq: Sequence[T],
+        bboxes_seq: Sequence[T],
+        labels_seq: Sequence[T]
 ) -> tf.data.Dataset:
-
-    tf_image_seq, tf_bboxes_seq, tf_labels_seq = np_to_tf(
+    tf_image_seq, tf_bboxes_seq, tf_labels_seq = to_tf(
         image_seq, bboxes_seq, labels_seq
     )
 
@@ -109,29 +107,6 @@ def tf_resize(
     )
 
 
-def tf_rotate_90(
-        image: tf.Tensor,
-        bboxes: tf.Tensor,
-        labels: tf.Tensor
-) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-    return _rotate_90(
-        image, bboxes, labels,
-        _tf_convert, tf.shape, tf.reshape, tf.transpose, tf.concat
-    )
-
-
-def tf_rotate_90_and_pad(
-        image: tf.Tensor,
-        bboxes: tf.Tensor,
-        labels: tf.Tensor
-) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-    return _rotate_90_and_pad(
-        image, bboxes, labels,
-        _tf_convert, tf.shape, tf.reshape, tf.transpose, tf.concat,
-        tf.where, tf.math.ceil, tf.math.floor, _tf_pad_image
-    )
-
-
 def tf_rotate(
         image: tf.Tensor,
         bboxes: tf.Tensor,
@@ -142,9 +117,9 @@ def tf_rotate(
         image, bboxes, labels, angle_deg,
         _tf_convert, tf.shape, tf.reshape, tf.expand_dims, tf.squeeze,
         _tf_pad_image, tf.range, _tf_round_to_int, tf.repeat, tf.tile,
-        tf.stack, tf.concat, tf.cos, tf.sin, tf.matmul, tf.clip_by_value,
-        _tf_gather_image, tf.identity, tf.reduce_max, tf.reduce_min,
-        tf.logical_and, tf.boolean_mask
+        tf.ones_like, tf.stack, tf.concat, tf.cos, tf.sin, tf.matmul,
+        tf.clip_by_value, _tf_gather_image, tf.identity,
+        tf.reduce_max, tf.reduce_min, tf.logical_and, tf.boolean_mask
     )
 
 
@@ -158,7 +133,25 @@ def tf_shear(
         image, bboxes, labels, angle_deg,
         _tf_convert, tf.shape, tf.reshape, tf.expand_dims, tf.squeeze,
         _tf_pad_image, tf.range, _tf_round_to_int, tf.repeat, tf.tile,
-        tf.stack, tf.concat, tf.tan, tf.matmul, tf.clip_by_value,
+        tf.ones_like, tf.stack, tf.concat, tf.tan, tf.matmul, tf.clip_by_value,
+        _tf_gather_image, tf.identity, tf.reduce_max, tf.reduce_min,
+        tf.logical_and, tf.boolean_mask
+    )
+
+
+def tf_translate(
+        image: tf.Tensor,
+        bboxes: tf.Tensor,
+        labels: tf.Tensor,
+        translate_height: int,
+        translate_width: int
+) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
+    return _translate(
+        image, bboxes, labels,
+        translate_height, translate_width,
+        _tf_convert, tf.shape, tf.reshape, tf.expand_dims, tf.squeeze,
+        _tf_pad_image, tf.range, _tf_round_to_int, tf.repeat, tf.tile,
+        tf.ones_like, tf.stack, tf.concat, tf.matmul, tf.clip_by_value,
         _tf_gather_image, tf.identity, tf.reduce_max, tf.reduce_min,
         tf.logical_and, tf.boolean_mask
     )
@@ -195,22 +188,6 @@ def tf_crop(
     )
 
 
-def tf_translate(
-        image: tf.Tensor,
-        bboxes: tf.Tensor,
-        labels: tf.Tensor,
-        translate_height: int,
-        translate_width: int
-) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-    return _translate(
-        image, bboxes, labels,
-        translate_height, translate_width,
-        _tf_convert, tf.shape, tf.reshape, tf.where, tf.abs, tf.concat,
-        tf.logical_and, tf.squeeze, tf.clip_by_value, tf.boolean_mask,
-        _tf_pad_image
-    )
-
-
 class TFResize:
 
     def __init__(self, dest_size: Tuple[int, int]) -> None:
@@ -247,7 +224,7 @@ class TFRandomTransform:
             *args: Any,
             **kwargs: Any
     ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-
+        # Make sure inputs are in the needed format.
         image = _tf_convert(image)
         bboxes = _tf_convert(bboxes)
         labels = _tf_convert(labels)
@@ -297,46 +274,6 @@ class TFRandomFlipUpDown(TFRandomTransform):
         return super().__call__(image, bboxes, labels)
 
 
-class TFRandomRotate90(TFRandomTransform):
-
-    def __init__(
-            self,
-            probability: float = 0.7,
-            seed: Optional[int] = None
-    ) -> None:
-        super().__init__(tf_rotate_90, probability, seed)
-
-    def __call__(
-            self,
-            image: tf.Tensor,
-            bboxes: tf.Tensor,
-            labels: tf.Tensor,
-            *args: Any,
-            **kwargs: Any
-    ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-        return super().__call__(image, bboxes, labels)
-
-
-class TFRandomRotate90AndPad(TFRandomTransform):
-
-    def __init__(
-            self,
-            probability: float = 0.7,
-            seed: Optional[int] = None
-    ) -> None:
-        super().__init__(tf_rotate_90_and_pad, probability, seed)
-
-    def __call__(
-            self,
-            image: tf.Tensor,
-            bboxes: tf.Tensor,
-            labels: tf.Tensor,
-            *args: Any,
-            **kwargs: Any
-    ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-        return super().__call__(image, bboxes, labels)
-
-
 class TFRandomRotate(TFRandomTransform):
 
     def __init__(
@@ -357,7 +294,6 @@ class TFRandomRotate(TFRandomTransform):
             *args: Any,
             **kwargs: Any
     ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-
         angle_deg = \
             _tf_convert(self.angle_deg_range[1] - self.angle_deg_range[0]) \
             * self._rand_fn() + _tf_convert(self.angle_deg_range[0])
@@ -385,7 +321,6 @@ class TFRandomShear(TFRandomTransform):
             *args: Any,
             **kwargs: Any
     ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-
         angle_deg = \
             _tf_convert(self.angle_deg_range[1] - self.angle_deg_range[0]) \
             * self._rand_fn() + _tf_convert(self.angle_deg_range[0])
@@ -393,42 +328,6 @@ class TFRandomShear(TFRandomTransform):
         return super().__call__(image, bboxes, labels, angle_deg)
 
 
-class TFRandomCrop(TFRandomTransform):
-
-    def __init__(
-            self,
-            crop_height_fraction_range: Tuple[float, float] = (0.7, 0.9),
-            crop_width_fraction_range: Tuple[float, float] = (0.7, 0.9),
-            probability: float = 0.7,
-            seed: Optional[int] = None
-    ) -> None:
-        super().__init__(tf_crop, probability, seed)
-        self.crop_height_fraction_range = crop_height_fraction_range
-        self.crop_width_fraction_range = crop_width_fraction_range
-
-    def __call__(
-            self,
-            image: tf.Tensor,
-            bboxes: tf.Tensor,
-            labels: tf.Tensor,
-            *args: Any,
-            **kwargs: Any
-    ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-
-        offset_height, offset_width, cropped_height, cropped_width = \
-            _tf_get_random_crop_inputs(
-                tf.shape(image)[0], tf.shape(image)[1],
-                self.crop_height_fraction_range,
-                self.crop_width_fraction_range,
-                self._rand_fn
-            )
-
-        return super().__call__(
-            image, bboxes, labels,
-            offset_height, offset_width, cropped_height, cropped_width
-        )
-
-
 class TFRandomTranslate(TFRandomTransform):
 
     def __init__(
@@ -450,7 +349,6 @@ class TFRandomTranslate(TFRandomTransform):
             *args: Any,
             **kwargs: Any
     ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
-
         height_fraction, width_fraction = _get_random_size_fractions(
             self.translate_height_fraction_range,
             self.translate_width_fraction_range,
@@ -467,3 +365,38 @@ class TFRandomTranslate(TFRandomTransform):
         return super().__call__(
             image, bboxes, labels, translate_height, translate_width
         )
+
+
+class TFRandomCrop(TFRandomTransform):
+
+    def __init__(
+            self,
+            crop_height_fraction_range: Tuple[float, float] = (0.7, 0.9),
+            crop_width_fraction_range: Tuple[float, float] = (0.7, 0.9),
+            probability: float = 0.7,
+            seed: Optional[int] = None
+    ) -> None:
+        super().__init__(tf_crop, probability, seed)
+        self.crop_height_fraction_range = crop_height_fraction_range
+        self.crop_width_fraction_range = crop_width_fraction_range
+
+    def __call__(
+            self,
+            image: tf.Tensor,
+            bboxes: tf.Tensor,
+            labels: tf.Tensor,
+            *args: Any,
+            **kwargs: Any
+    ) -> Tuple[tf.Tensor, tf.Tensor, tf.Tensor]:
+        offset_height, offset_width, cropped_height, cropped_width = \
+            _tf_get_random_crop_inputs(
+                tf.shape(image)[0], tf.shape(image)[1],
+                self.crop_height_fraction_range,
+                self.crop_width_fraction_range,
+                self._rand_fn
+            )
+
+        return super().__call__(
+            image, bboxes, labels,
+            offset_height, offset_width, cropped_height, cropped_width
+        )
